@@ -63,7 +63,7 @@ def main():
             commands.apps_run(image=args.image, name=args.name, container_size=args.container_size,
                               target_num_containers=args.target_num_containers, run_command=args.run_command,
                               entrypoint=args.entrypoint, container_ports=args.port, container_envvars=args.env,
-                              linked_to_applications=args.link, autorestart=args.autorestart,
+                              links=args.link, autorestart=args.autorestart,
                               autoreplace=args.autoreplace, autodestroy=args.autodestroy, roles=args.role,
                               sequential=args.sequential)
         elif args.subcmd == 'scale':
